# USB8VI4 test.
# N. J. Halse 17-08-18
# using serial commands to an FTDI serial port.

# Modified as an example test program NJH 03/02/20


import serial    # serial inteface
import time      # used for system timings
import sys       # display of data read back from the board                          .
import signal    # intercept SIGINT (Ctrl-C) to end demo.

# Define the port, baudrate and timeout (in sec) to use '/dev/ttyUSB0, 9600, timeout=1'
SER_PORT_LIN = '/dev/ttyUSB0'       # Set this to the port that FTDI assigned to the USB4 if running Linux
SER_PORT_WIN = 'COM15'              # Set this to the port that FTDI assigned to the USB4 if running Windows
SER_PORT_Baud = 9600                # Set the baud rate
EDdealy = 0.02                      # Delay after sending a command to the EasyDAQ board to allow for the outputs to be set and the switches to debounce
EDdealy2 = 0.2                      # general delay time must be greater than EDdealy

BUFFER_SIZE = 1 # How many bytes to read back from board

# Introduction
print ("\nEasyDaq USB demonstration of the USB8VI4xxx board")
print ("(Hit Ctrl-c to end)\n")

# Open port
ser = serial.Serial(SER_PORT_WIN)   # Open the port (select WIN for Windows and LIN for Linux)
print (ser.name)                    # for debug

# Define a signal handler to catch when the user quits using Ctrl-C and then tidy up
def signal_handler(signal, frame):
 print('\n\n\n      *** Thank you for trying the EasyDaq USB8VI4 *** \nFor further information please visit http://www.easydaq.co.uk\n')
 MESSAGE = b'\x43\x00'              # PIC port B to All on
 ser.write(MESSAGE)
 time.sleep(3)
 ser.close()
 sys.exit(0) 

# Define the relay control function
def set_relays(MESSAGE):
 ser.write(MESSAGE)                 # Send the setup data to the EasyDAQ board
 time.sleep(EDdealy)                # Delay to allow EasyDAQ board to switch the relays

signal.signal(signal.SIGINT, signal_handler) # Register the signal handler for the CTRL-C termination of the program

# Define reading port B
def readB():
     MESSAGE = b'\x41\x00'              # Read port B
     set_relays(MESSAGE)
     time.sleep(EDdealy2)
     BYTEIN = ser.read()             # get the byte
     BYTEIN = ord(BYTEIN)
     print ('Input byte B',"%#5.2X"% (BYTEIN),'  ',format(BYTEIN,'#010b'), end = '')

# Define reading port C
def readC():
     MESSAGE = b'\x44\x00'              # Read port C
     set_relays(MESSAGE)
     time.sleep(EDdealy2)
     BYTEIN = ser.read()             # get the byte
     BYTEIN = ord(BYTEIN)
     print (' Input byte C',"%#5.2X"% (BYTEIN),'  ',format(BYTEIN,'#010b'))

def readBC():
     readB()
     readC()

# Configure the USB8VI4 ports for input/output
MESSAGE = b'\x42\xFF'               # Set PIC port B to inputs
ser.write(MESSAGE)                  # Send the command
time.sleep(EDdealy)                 # Allow the EasyDAQ board time to set the putputs

MESSAGE = b'\x45\xF0'               # Set PIC port C low nibble to output, upper nibble to input
ser.write(MESSAGE)                  # Send the command
time.sleep(EDdealy)                 # Allow the EasyDAQ board time to set the putputs

# The main program loop
while True:
 MESSAGE = b'\x46\x01'              # Set PIC port C to 0x01 (Relays 1 on)
 set_relays(MESSAGE)
 time.sleep(EDdealy)
 readBC()
 MESSAGE = b'\x46\x00'              # Set PIC port C to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(EDdealy2)
 MESSAGE = b'\x46\x02'              # Set PIC port C to 0x02 (Relays 2 on)
 set_relays(MESSAGE)
 time.sleep(EDdealy)
 readBC()
 MESSAGE = b'\x46\x00'              # Set PIC port C to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(EDdealy2)
 MESSAGE = b'\x46\x04'              # Set PIC port C to 0x04 (Relays 3 on)
 set_relays(MESSAGE)
 time.sleep(EDdealy)
 readBC()
 MESSAGE = b'\x46\x00'              # Set PIC port C to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(EDdealy2)
 MESSAGE = b'\x46\x08'              # Set PIC port C to 0x08 (Relays 4 on)
 set_relays(MESSAGE)
 time.sleep(EDdealy)
 readBC()
 MESSAGE = b'\x46\x00'              # Set PIC port C to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(EDdealy2)






